/**
 * Helper class to layout a given
 * object as ascii table.
 * 
 * @author Heiner Kcker
 */
public class AsciToStringHelper
{
    public static String asciToString( //-- 
            final AsciTableLayoutableInterface[] pObjArr)
    {
        if ( pObjArr != null)
        {
            //nur fr performance test: return "";
        }
        if ( pObjArr == null )
        {
            return " is null ";
        }
        if ( pObjArr.length < 1 )
        {
            return " is empty ";
        }
        AsciTableLayoutableInterface pObj = pObjArr[0];
        if (pObj == null)
        {
            return " first entry is null ";
        }
        AsciiTable.Cell[][] table = new AsciiTable.Cell[ pObjArr.length + 1 ][ pObj.asciTableColumnNames().length ];
        
        for (int i = 0; i < pObj.asciTableColumnNames().length; i++)
        {
            table[ 0 ][ i ] = new AsciiTable.Cell(pObj.asciTableColumnNames()[i]);
        }
        for (int i = 0; i < pObjArr.length; i++)
        {
            pObj = pObjArr[i];
            if (pObj != null)
            {
                final int j = i + 1;
                for (int k = 0; k < pObj.asciTableColumnNames().length; k++)
                {
                    final Object cellValue = pObj.asciTableColumnContent(k);
                    final String cellStr;
                    if ( cellValue instanceof AsciTableLayoutableInterface[])
                    {
                        cellStr = 
                            cutRight( 
                                asciToString( (AsciTableLayoutableInterface[]) cellValue ),
                                "\n" );
                    }
                    else
                    {
                        cellStr = String.valueOf( cellValue );
                    }
                    table[ j ][ k ] = new AsciiTable.Cell( cellStr );
                    if (cellValue instanceof Number)
                    {
                        table[ j ][ k ].setAlignment( AsciiTable.RIGHT_ALIGNMENT );
                    }
                }
            }
        }
        return AsciiTable.buildLayout(//--
                table, AsciiTable.DOUBLE_LINE, //--
                AsciiTable.DOUBLE_LINE, //--
                AsciiTable.SINGLE_LINE, //--
                AsciiTable.SINGLE_LINE, //--
                AsciiTable.DOUBLE_LINE);
    }

    /**
     * Teilstring von String rechts abschneiden, wenn mglich
     *
     * @param srcStr Original-String
     * @param cutStr abzuschneidender String
     * @return abgeschnittener String
     */
    public static String cutRight( 
            final String srcStr, 
            final String cutStr) {
      if (srcStr == null || cutStr == null) 
      {
        return srcStr;
      }

      String  retStr = srcStr;

      if (retStr.endsWith(cutStr)) 
      {
        retStr = retStr.substring(0, retStr.length() - cutStr.length());  // cutStr abschneiden
      }

      return retStr;
    }// end method cutRight

    /**
     * Test.
     * 
     * @param args unused
     */
    public static void main(String[] args)
    {
        final int MAX_COUNT = 4;
        final Test1[] test1Arr = new Test1[ MAX_COUNT ];
        for (int i = 0; i < MAX_COUNT; i++)
        {
            final Test2[] test2Arr = new Test2[ MAX_COUNT ];
            for (int j = 0; j < MAX_COUNT; j++)
            {
                test2Arr[ j ] = new Test2( ( i * MAX_COUNT ) + j , "child" + i + "_" + j , i );
            }
            test1Arr[ i ] = new Test1(i, "parent" + i , test2Arr );
        }
        //System.out.println( asciToString( test1Arr ) );
        
        final Test0 test0 = new Test0(test1Arr);

        //set break point for debug perspective / variables view here
        System.out.println( test0 );
        
    }


}
